Tween

Struct Tween 

pub struct Tween<T: Animatable> { /* private fields */ }
An animation that interpolates between two values using Timing.

Examples

use aura_anim_core::{Tween, timing::Timing};
use std::time::Duration;

let mut tween = Tween::between(0.0_f32, 10.0, Timing::new(100.0));

tween.tick(Duration::from_millis(50));
assert_eq!(*tween.value(), 5.0);

tween.tick(Duration::from_millis(50));
assert!(tween.is_completed());
assert_eq!(*tween.value(), 10.0);

Implementations

Source

impl<T: Animatable> Tween<T>

pub fn new(value: T) -> Self

Creates an idle tween with the default 200 millisecond timing.

pub fn with_timing(value: T, timing: Timing) -> Self

Creates an idle tween with the provided timing.

pub fn between(from: T, to: T, timing: Timing) -> Self

Creates a running tween from from to to.

pub fn value(&self) -> &T

Returns the current interpolated value.

pub fn from(&self) -> &T

Returns the value at the start of the current transition.

pub fn target(&self) -> &T

Returns the target value of the current transition.

pub const fn timing(&self) -> Timing

Returns the timing configuration.

pub const fn state(&self) -> AnimationState

Returns the current lifecycle state.

pub fn is_active(&self) -> bool

Returns whether the tween is currently running.

pub fn is_completed(&self) -> bool

Returns whether the tween has completed.

pub fn transition_to(&mut self, target: T)

Starts a transition from the current value to target.

pub fn tick(&mut self, delta: impl Into<Duration>)

Advances the tween by delta.

pub fn pause(&mut self)

Pauses the tween when it is running.

pub fn resume(&mut self)

Resumes the tween when it is paused.

pub fn cancel(&mut self)

Cancels the tween unless it is already completed or canceled.

pub fn seek(&mut self, progress: f32)

Seeks to normalized progress within the complete timing interval.

pub fn finish(&mut self)

Moves the tween to its final value and completed state.