Core animation primitives, timing types, composition utilities, and runtime storage.
Re-exports
pub use interpolate::InterpolationProgress;pub use presence::Presence;pub use runtime::AnimationCommand;pub use runtime::Motion;pub use runtime::MotionRuntime;pub use runtime::RetainPolicy;pub use spring::Spring;pub use spring::SpringConfig;pub use timeline::Hold;pub use timeline::Parallel;pub use timeline::Sequence;pub use timeline::Timeline;pub use traits::Animatable;pub use traits::Animation;pub use traits::AnimationState;pub use traits::Interpolate;pub use tween::Tween;pub use tween::TweenState;
Modules
- interpolate
- Interpolation progress and built-in interpolation implementations.
- keyframes
- Keyframe definitions and keyframe-based animations.
- presence
- Animated visibility lifecycle management.
- runtime
- Runtime storage, typed handles, and animation commands.
- spring
- Spring-based animations.
- timeline
- Sequential, parallel, and fixed-duration animation composition.
- timing
- Timing configuration and elapsed-time normalization.
- traits
- Core traits implemented by animatable values and animation sources.
- tween
- Duration-based interpolation animations.
Derive Macros
- Animatable
- Derives field-by-field interpolation for a struct.