Runtime storage, typed handles, and animation commands.
Structs
- Motion
- A typed handle to an animation stored in a
MotionRuntime. - Motion
Runtime - Stores animations and advances their active values.
Enums
- Animation
Command - A lifecycle command that can be sent to a runtime-managed animation.
- Retain
Policy - Controls whether the runtime retains an animation after it settles.