pub struct Parallel<T: Animatable> { /* private fields */ }Expand description
Runs child animations together and composes their output values.
Implementations
Sourceimpl<T: Animatable> Parallel<T>
impl<T: Animatable> Parallel<T>
Sourcepub fn new(initial: T, compose: impl Fn(&[T]) -> T + 'static) -> Self
pub fn new(initial: T, compose: impl Fn(&[T]) -> T + 'static) -> Self
Creates an empty parallel animation with an output compositor.
Sourcepub fn with(self, animation: impl Animation<T>) -> Self
pub fn with(self, animation: impl Animation<T>) -> Self
Appends an animation and returns the updated parallel composition.