Timing

Struct Timing 

pub struct Timing { /* private fields */ }
Timing configuration shared by duration-based animations.

Examples

use aura_anim_core::timing::{Delay, Direction, Timing};

let timing = Timing::ease_out(250.0)
    .with_delay(Delay::from_millis(50.0))
    .with_direction(Direction::Alternate)
    .with_iterations(2);

assert_eq!(timing.duration().as_millis(), 250.0);
assert_eq!(timing.total_duration().unwrap().as_millis(), 550.0);

Implementations

Source

impl Timing

pub fn new(duration_ms: impl Into<Duration>) -> Self

Creates a timing value with a duration in milliseconds.

pub fn linear(duration_ms: impl Into<Duration>) -> Self

Creates a linear timing with a duration in milliseconds.

pub fn ease_in(duration_ms: impl Into<Duration>) -> Self

Creates an ease-in timing with a duration in milliseconds.

pub fn ease_out(duration_ms: impl Into<Duration>) -> Self

Creates an ease-out timing with a duration in milliseconds.

pub fn ease_in_out(duration_ms: impl Into<Duration>) -> Self

Creates an ease-in-out timing with a duration in milliseconds.

pub const fn duration(&self) -> Duration

Returns the duration of the timing.

pub const fn delay(&self) -> Delay

Returns the delay of the timing.

pub const fn direction(&self) -> Direction

Returns the direction of the timing.

pub const fn easing(&self) -> Easing

Returns the easing curve of the timing.

pub const fn iterations(&self) -> IterationCount

Returns the number of iterations of the timing.

pub const fn with_duration(self, duration: Duration) -> Self

Sets the duration.

pub const fn with_delay(self, delay: Delay) -> Self

Sets the start delay.

pub const fn with_direction(self, direction: Direction) -> Self

Sets the playback direction.

pub const fn with_easing(self, easing: Easing) -> Self

Sets the easing curve.

pub fn with_iterations(self, iterations: impl Into<IterationCount>) -> Self

Sets the iteration count.

pub fn active_duration(self) -> Option<Duration>

Returns the total active duration when the timing has a finite length.

pub fn total_duration(self) -> Option<Duration>

Returns the total duration including delay when finite.